#
#  OpenDBX rpm spec file
#
#  By default OpenDBX is build with this backends:
#  - mysql
#  - pgsql
#  - sqlite3
#  to disable use --without [module-name]
#
#  Optional supported backends are:
#  - sqlite
#  to enable use --with [module-name]
#

Name:    opendbx
Version:    1.0.3
Release:    1%{?dist}
Summary:    Unified database layer with a clean and lightweight interface
Group:    Development/Libraries
License:    LGPL
URL:    http://www.linuxnetworks.de/opendbx/
Source0:    http://www.linuxnetworks.de/opendbx/download/%{name}-%{version}.tar.gz
BuildRoot:    %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)


%description
OpenDBX provides a clean and lightweight API for interfacing native relational
database APIs in a consistent way. By using the OpenDBX API you don't have to
adapt your program to the different database APIs by yourself.


%package devel
Summary:    OpenDBX development headers
Group:    Development/Libraries
Requires:    %{name} = %{version}

%description devel
Header files for the OpenDBX database abstraction library


%if %{!?_without_mysql:1}%{?_without_mysql:0}
%package mysql
Summary:    MySQL backend for OpenDBX
Group:    Development/Libraries
Requires:    %{name} = %{version}
Requires:    mysql
BuildRequires:    mysql-devel

%description mysql
MySQL backend for the OpenDBX database abstraction library
%endif


%if %{!?_without_pgsql:1}%{?_without_pgsql:0}
%package pgsql
Summary:    PostgreSQL backend for OpenDBX
Group:    Development/Libraries
Requires:    %{name} = %{version}
Requires:    postgresql
BuildRequires:    postgresql-devel

%description pgsql
PostgreSQL backend for the OpenDBX database abstraction library
%endif


%if %{!?_without_sqlite3:1}%{?_without_sqlite3:0}
%package sqlite3
Summary:    SQLite3 backend for OpenDBX
Group:    Development/Libraries
Requires:    %{name} = %{version}
Requires:    sqlite >= 3.0
BuildRequires:    sqlite-devel >= 3.0

%description sqlite3
SQLite3 backend for the OpenDBX database abstraction library
%endif


%if %{?_with_sqlite:1}%{!?_with_sqlite:0}
%package sqlite
Summary:    SQLite backend for OpenDBX
Group:    Development/Libraries
Requires:    %{name} = %{version}
Requires:    sqlite < 3.0
BuildRequires:    sqlite-devel < 3.0

%description sqlite
SQLite backend for the OpenDBX database abstraction library
%endif


%prep
%setup -q


%build
%configure \
    --with-backends="\
%{!?_without_mysql:mysql }\
%{!?_without_pgqql:pgsql }\
%{!?_without_sqlite3:sqlite3 }\
%{?_with_sqlite:sqlite }\
" \
%{!?_without_mysql:CPPFLAGS="-I/usr/include/mysql"} \
%{!?_without_mysql:LDFLAGS="-L/usr/lib/mysql"} \
CFLAGS="-Wall -ansi -pedantic -std=c99"

make %{?_smp_mflags}


%install
if test "$RPM_BUILD_ROOT" != "/"; then rm -rf $RPM_BUILD_ROOT; fi
make install DESTDIR=$RPM_BUILD_ROOT/


%clean
if test "$RPM_BUILD_ROOT" != "/"; then rm -rf $RPM_BUILD_ROOT; fi


%files
%defattr(-,root,root,-)
%{_libdir}/libopendbx.so.*
%{_datadir}/locale/de/LC_MESSAGES/opendbx.mo
%{_datadir}/locale/en@quot/LC_MESSAGES/opendbx.mo
%doc AUTHORS COPYING ChangeLog NEWS README TODO


%files devel
%defattr(-,root,root,-)
%{_includedir}/odbx.h
%{_libdir}/libopendbx.a
%{_libdir}/libopendbx.la
%{_libdir}/libopendbx.so


%if %{!?_without_mysql:1}%{?_without_mysql:0}
%files mysql
%defattr(-,root,root,-)
%{_libdir}/opendbx/libmysqlbackend.a
%{_libdir}/opendbx/libmysqlbackend.la
%{_libdir}/opendbx/libmysqlbackend.so*
%endif


%if %{!?_without_pgsql:1}%{?_without_pgsql:0}
%files pgsql
%defattr(-,root,root,-)
%{_libdir}/opendbx/libpgsqlbackend.a
%{_libdir}/opendbx/libpgsqlbackend.la
%{_libdir}/opendbx/libpgsqlbackend.so*
%endif


%if %{!?_without_sqlite3:1}%{?_without_sqlite3:0}
%files sqlite3
%defattr(-,root,root,-)
%{_libdir}/opendbx/libsqlite3backend.a
%{_libdir}/opendbx/libsqlite3backend.la
%{_libdir}/opendbx/libsqlite3backend.so*
%endif


%if %{?_with_sqlite:1}%{!?_with_sqlite:0}
%files sqlite
%defattr(-,root,root,-)
%{_libdir}/opendbx/libsqlitebackend.a
%{_libdir}/opendbx/libsqlitebackend.la
%{_libdir}/opendbx/libsqlitebackend.so*
%endif


%changelog
* Tue Jun 13 2006 Kees Monshouwer <mind|monshouwer_com> 1.0.1-1
- Fixed a few minor problems
- Added conditional build support

* Mon Jun 12 2006 Kees Monshouwer <mind|monshouwer_com> 1.0.0-1
- Initial build for CentOS 4.3
